module AdvancedDCL
  module Contour
    def param_init
      @param = Parameter.new(AdvancedDCL.param)
      @param.init("indexmj", Fixnum, "indexmj", "indexmjget", 3, 2)
      @param.init("indexmn", Fixnum, "indexmn", "indexmnget", 3, 2)
      @param.init("label", TrueClass, "udlset", "udlget", 0, 0)
      @param.init("lcent", TrueClass, "udlset", "udlget", 0, 0)
      @param.init("ldash", TrueClass, "udlset", "udlget", 0, 0)
      @param.init("idash", Fixnum, "udiset", "udiget", 0, 0)
      @param.init("isolid", Fixnum, "udiset", "udiget", 0, 0)
      @param.init("icycle", Fixnum, "udiset", "udiget", 0, 0)
      @param.init("nlev", Fixnum, "udiset", "udiget", 0, 0)
      @param.init("labelsize", Float, "labelsize", "labelsizeget", 3, 2)
      @param.init("lmsg", TrueClass, "udlset", "udlget", 0, 0)
      @param.init("titlesize", Float, "titlesize", "titlesizeget", 3, 2)
      @param.init("xttl", Float, "udrset", "udrget", 0, 0)
      @param.init("iundef", Fixnum, "udiset", "udiget", 0, 0)
      @param.init("labelfmt", String, "udsfmt", "udqfmt", 1, 1)

      @temp_param = @param.dup
    end
    
    private :param_init

#------------------- method for parameters----------------------

    def set(key, val)
      @param[key] = val
    end

    def gcla(max, min, dx)
      DCL.udgcla(max, min, dx)
    end

    def gclb(z, dx)
      DCL.udgclb(z, z.shape(0), z.shape(0), z.shape(1), dx)
    end

    def sclv(zlev, index, itype, clv, hl)
      DCL.udsclv(zlev, index, itype, clv, hl)
    end

    def dclv(zlev)
      DCL.uddclv(zlev)
    end

    def iclv
      DCL.udiclv
    end

    def intervalget(nlev)
      DCL.rudlev(nlev)
    end
    
    def levelget
      nelv = DCL.udqcln
      levels = []
      for i in 0..nlev-1
	status = DCL.udqclv(i)
	levels.push(status[0])
      end
      levels
    end

    def sgxa(xp)
      DCL.uwsgxa(xp, xp.length)
    end

    def sgya(yp)
      DCL.uwsgya(yp, yp.length)
    end

    def sgxb(uxmin, uxmax, nx)
      DCL.uwsgxb(uxmin, uxmax, nx)
    end

    def sgyb(uymin, uymax, ny)
      DCL.uwsgyb(uymin, uymax, ny)
    end

#----------------------------------------------------------
#------------ draw method ----------------------
    def draw(data, temp=nil)
      @param.sync
      @backup = @temp_param.set(temp, @param)
      @temp_param.sync

      Fig.settrf
    
      nx = data.shape[0]
      ny = data.shape[1]
      nb = DCL.glpget("nbitspw")
      nbr = (3*((nx+2)*(ny+2)*2.0/nb + 1)).ceil
      DCL.udcntz(data, data.shape[0], data.shape[0], data.shape[1], nbr)
      @backup.sync
      @temp_param.clear
    end

    module_function :param_init
    module_function :draw
    module_function :gcla
    module_function :gclb
    module_function :sclv
    module_function :dclv
    module_function :iclv
    module_function :intervalget
    module_function :levelget
    module_function :sgxa
    module_function :sgxb
    module_function :sgya
    module_function :sgyb

    param_init

#------------------- singleton methods ----------------------
  
    def @param.indexmj(index)
      DCL.udiset("indxmj", index)
    end

    def @param.indexmjget
      DCL.udiget("indxmj")
    end

    def @param.indexmn(index)
      DCL.udiset("indxmn", index)
    end

    def @param.indexmnget
      DCL.udiget("indxmn")
    end

    def @param.labelsize(size)
      DCL.udrset("rsizel", size)
    end

    def @param.labelsizeget
      DCL.udrget("rsizel")
    end

    def @param.titlesize(size)
      DCL.udrset("rsizet", size)
    end

    def @param.titlesizeget
      DCL.udrget("rsizet")
    end

#----------------------------------------------------------

    @param.keys.each{|i|
      eval "def #{i}; @param['#{i}']; end"
      eval "def #{i}=(val); set('#{i}', val); end"
    }
  
    @param.keys.each{|i|
      eval "module_function :#{i}"
      eval "module_function :#{i}="
    }
  end
end
