require "num/numarray"
require "advanced"

include AdvancedDCL
include Math


nx = 19
ny = 19
xmin = 0
xmax = 360
dx1 = 10
dx2 = 60
ymin = -90
ymax = 90
my = 7
nc = 3
drad = PI/180
dz = 0.05
p = NumArray.new(Float, nx, ny)
uy1 = NumArray.new(Float, ny)
uy2 = NumArray.new(Float, my)

#-- data ---
ch = ['SP ', '60S', '30S', 'EQ ', '30N', '60N', 'NP ']

for j in 0..ny-1
  for i in 0..nx-1
    alon = (xmin + (xmax-xmin)*i/(nx-1)) * drad
    alat = (ymin + (ymax-ymin)*j/(ny-1)) * drad
    slat = sin(alat)
    p[i,j] = cos(alon) * (1-slat**2) * sin(2*PI*slat) + dz
  end
end

uy1.span(ymin, (ymax-ymin)/(ny-1).to_f)
uy1 = (uy1*drad).sin
uy2.span(ymin, (ymax-ymin)/(my-1).to_f)
uy2 = (uy2*drad).sin

#-- graph ---
devopen("X")

Frame.new

Fig.window=[xmin.to_f, xmax.to_f, uy1[0], uy1[ny-1]]
Fig.viewport=[0.2, 0.8, 0.2, 0.8]
Fig.transnum=1

Axis::Lin.xaxdv('B', dx1, dx2)
Axis::Lin.xaxdv('T', dx1, dx2)
Axis::Lin.xsttl('B', 'LONGITUDE', 0.0)

Axis::Lin.yaxlb('L', uy1, uy2, ch)
Axis::Lin.yaxlb('R', uy1, uy2, ch)
Axis::Lin.ysttl('L', 'LATITUDE', 0.0)

Contour.sgxb(xmin, xmax, nx)
Contour.sgya(uy1, ny)

Contour.labelfmt('(F6.1)')
Contour.gclb(p, NX, NX, NY, 0.2)
Contour.sclv(0.1, 1, 4, ' ', 0.01)

Contour.draw(p)

devclose
